@@ -12,15 +12,16 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+from collections import UserList
 from functools import reduce
-from typing import List, Mapping, Sequence, Union, cast
+from typing import Dict, List, Mapping, MutableSequence, Optional, Sequence, Union, cast
 
 import numpy as np
 
 from .samples import FieldName, FieldValue, Sample
 
 
-class Batch(Sequence[Sample]):
+class Batch(UserList, MutableSequence[Sample]):
     """A class to represent a single batch.
 
     Args:
@@ -28,20 +29,16 @@ class Batch(Sequence[Sample]):
             should contain.
     """
 
-    def __init__(self, samples: Sequence[Sample]) -> None:
-        self._samples = samples
-
-    def __getitem__(self, index) -> Sample:
-        return self._samples[index]
-
-    def __len__(self) -> int:
-        return len(self._samples)
+    def __init__(self, samples: Optional[Sequence[Sample]] = None) -> None:
+        # constructor required; see https://docs.python.org/3.6/library/collections.html#collections.UserList
+        if samples is None:
+            samples = []
+        super().__init__(samples)
 
     def to_array(
             self,
             pad_with: Union[int, Mapping[FieldName, int]] = 0,
-            array_fn=None,
-    ) -> dict:
+    ) -> Dict[FieldName, np.ndarray]:
         """Convert the batch into `~numpy.ndarray`.
 
         Args:
@@ -49,19 +46,15 @@ class Batch(Sequence[Sample]):
                 also be a mapping from field names to padding number for
                 that field. Fields whose name is not in the mapping will
                 be padded with zeros.
-            array_fn: Callable to construct the array. Defaults to
-                `numpy.array` if not given.
 
         Returns:
             A mapping from field names to arrays whose first dimension
             corresponds to the batch size as returned by `len`.
         """
-        if not self._samples:
+        if not self:
             return {}
-        if array_fn is None:
-            array_fn = np.array
 
-        field_names = self._samples[0].keys()
+        field_names = self[0].keys()
 
         if isinstance(pad_with, int):
             pad_dict = {name: pad_with for name in field_names}
@@ -83,13 +76,13 @@ class Batch(Sequence[Sample]):
             # Pad the values
             data = self._pad(values, maxlens, paddings, 0)
 
-            arr[name] = array_fn(data)
+            arr[name] = np.array(data)
 
         return arr
 
     def _get_values(self, name: str) -> Sequence[FieldValue]:
         try:
-            return [s[name] for s in self._samples]
+            return [s[name] for s in self]
         except KeyError:
             raise KeyError(f"some samples have no field '{name}'")
 
