@@ -24,6 +24,9 @@ from .samples import FieldName, FieldValue, Sample
 
 class Vocab(UserDict, MutableMapping[FieldName, 'StringStore']):
     """A dictionary from field names to `StringStore` objects as the field's vocabulary."""
+    PAD_TOKEN = '<pad>'
+    UNK_TOKEN = '<unk>'
+
     def __getitem__(self, name: FieldName) -> 'StringStore':
         try:
             return super().__getitem__(name)
@@ -63,8 +66,8 @@ class Vocab(UserDict, MutableMapping[FieldName, 'StringStore']):
     def from_samples(
             cls,
             samples: Iterable[Sample],
-            pbar: Optional[tqdm] = None,
             options: Optional[Mapping[FieldName, dict]] = None,
+            pbar: Optional[tqdm] = None,
     ) -> 'Vocab':
         """Make an instance of this class from an iterable of samples.
 
@@ -121,8 +124,8 @@ class Vocab(UserDict, MutableMapping[FieldName, 'StringStore']):
             opts = options.get(name, {})
 
             # Padding and unknown tokens
-            pad = opts.get('pad', '<pad>')
-            unk = opts.get('unk', '<unk>')
+            pad = opts.get('pad', cls.PAD_TOKEN)
+            unk = opts.get('unk', cls.UNK_TOKEN)
             inits = []
             if name in seqfield and pad is not None:
                 inits.append(pad)
